@@ -1,19 +1,17 @@
-from datetime import datetime, timedelta
-
-from sp_api.api import Reports, Orders
+from sp_api.api import Reports
 from sp_api.base import Marketplaces, Schedules
 
 
 def test_create_report():
-    print(Reports().create_report(reportType='GET_FBA_MYI_ALL_INVENTORY_DATA'))
+    print(Reports(marketplace=Marketplaces.DE).create_report(reportType='GET_MERCHANT_LISTINGS_ALL_DATA'))
 
 
 def test_get_report():
-    print(Reports().get_report('600333018624'))
+    print(Reports(marketplace=Marketplaces.DE).get_report(''))
 
 
 def test_get_report_document_w_decrypt():
-    res = Reports().get_report_document('5',
+    res = Reports(marketplace=Marketplaces.DE).get_report_document('',
                                         decrypt=True, file=open('output.tsv', 'w+'))
     print(res)
     assert 'document' in res.payload
@@ -27,18 +25,19 @@ def test_get_report_document_n_decrypt():
 
 def test_create_report_schedule():
     res = Reports().create_report_schedule(reportType='GET_FLAT_FILE_OPEN_LISTINGS_DATA', period=Schedules.HOURS_8.value)
-    print(res)
     assert res.errors is None
     assert 'reportScheduleId' in res.payload
 
 
 def test_delete_schedule_by_id():
-    res = Reports().delete_report_schedule('5000d4018615')
+    res = Reports().delete_report_schedule('')
     print(res)
     assert res.errors is None
 
 
 def test_get_schedule_by_id_existing_schedule():
-    res = Reports().get_report_schedule('5000401d8615')
+    res = Reports().get_report_schedule('')
     print(res)
     assert res.errors is None
+
+
